#! /bin/bash
#
# Usage:
#
# ./debughl7.sh [<port>] <-k>
# where <port> is the port to listen on.  Logs and pids will have this number appended to the filename.
# -k will kill the running receivemessage on the specified port.
# (if no -k arg, the script will restart receiveMessage)

# Source the setenv file
. ~/etc/setenv.sh

if [ -z "$1" ]; then
    port=7532
    hl7pidfile=~/var/run/hl7.pid
else
    port=$1
    hl7pidfile=~/var/run/hl7.pid.$port
fi

if [ -n "$2" -a "-k" == "$2" ]; then
    killme=1
fi


hl7log=~/hl7.log.$port
hl7logdated=~/var/log/hl7.$(date +"%m-%d-%H%M%S").log.$port

# Stop hl7 server
if [ -e "$hl7pidfile" ]; then
    hl7pid=$(cat $hl7pidfile)
    echo "Stopping Hl7 server: process id $hl7pid"
    kill $hl7pid
    sleep 5
fi

# Copy the log file and date it if one exists
if [ -e "$hl7log" ]
    then echo "Copying the log file to $hl7logdated"
    mv $hl7log $hl7logdated
fi

# If killme is set, don't go past here.
[ -n "$killme" ] && exit 0

# Restart in debug mode
echo "Starting in debug mode. Logging to $hl7log"
~/component/hl7/bin/receiveMessage -V -D -n 10 -p $port > $hl7log 2>&1 & echo $! > $hl7pidfile 

