#!/bin/bash

. $HOME/etc/setenv.sh

NOTFOUND="NotOnArchive.stys"
CUTOFFDATE=`date +%Y%m%d --date="14 days ago"`
#CUTOFFDATE="20070814"
GOODARCHPARTS="a2"
ONDISKSTYS="ondatadicom.stys"
RMCANDIDATES="rmcandidates.stys"
filelist="list.files"
ARCHCHK="archive.check"

function usage {
  echo -e "\nUSAGE: $0  Number"
  echo -e "\n\t where Number is the number of studies to attempt to remove"
  echo -e "\n"
}


function isArchived() {

    # returns 0 (success) if archived
    cfStudy=$1
    cfFile=$2
    BDIR=$(pwd)
    [ -z "$cfStudy" -o -z "$cfFile" ] && return 2

    ARCHDIR=`echo "select ARCHDIR from Archive where STYIUID='$cfStudy'" | $MYSQL_HOME/bin/mysql -N imagemedical`
    #  echo ~/var/archive/$ARCHDIR/$Study/$File
    echo -e  "\t\t\tArchive dir: $ARCHDIR" >&2
    if [ -f ~/var/archive/$ARCHDIR/$cfStudy/$cfFile ] ; then
        echo -e "\t\t\t$cfFile OK"
        return 0
    else
        echo -e "\t\t\t$cfFile ERROR [Not FOUND]"
        return 1
    fi
}

#
#  given an input file with styiuids listed, $1, this function
#  will build a listfile for use with component/tools/isarchived.sh
#  and write this file out to the second argument, $2
#
function checkAndRemove {
  if [ -z "$1"  ] ; then
     echo "Input file: $1 "
     exit -1
  fi
  TOTAL=`cat $1 | wc -l`
  i=0
  for s in `cat $1 `
  do
     i=$((i+1))
     echo "C[$i / $TOTAL]: $s"
     CLEANIT="YES"
     OBJS=`ls $HOME/data/dicom/$s 2>nada.txt`
     for o in `echo $OBJS`
     do
         isArchived $s $o
         if [ "$?" != "0" ] ; then
            CLEANIT="NO"
         fi
     done
     if [ "$CLEANIT" = "YES" ] ; then
        echo -e "\tRemoving $s"
        ~/component/cases/rmstudy.sh $s
        ~/checkrefs.sh -s $s -R
     else
        echo -e "\t!!!!NOT REMOVING $s !!!!!"
        echo "$s" >> $NOTFOUND
     fi
  done
} # End function checkAndRemove

#
#  function findcandidates
#
function findcandidates {
    if [ -z "$1" ] ; then
       echo "Input file: $1 missing"
       exit -1
    fi
    for sty in `cat $1 | head -n $2`
    do
       iscandidate=`echo "select STYIUID from Archive where STYIUID = '$sty' AND THEDATE < $CUTOFFDATE " | $HOME/component/mysql/bin/mysql -N imagemedical`
       if [ ! -z "$iscandidate" ] ; then
          OBJPRESENT=`ls $HOME/data/dicom/$sty`
          if [ ! -z "$OBJPRESENT" ] ; then
            echo "$sty" >> $RMCANDIDATES
            echo -e "\t$iscandidate is a candidate for removal"
          else
            echo -e "\t$iscandidate has an empty data/dicom/ DIRECTORY"
          fi
       else
          echo -e "\t$sty is NOT a candidate for removal!!"
       fi
    done
} # End function findcandidates

###########################################################
#  Main
###########################################################

if [ -z "$1" ] ; then
  usage
  exit 1
fi

echo -e "\n\n\t Building on disk list of studies and storing it in $ONDISKSTYS"
ls $HOME/data/dicom > $ONDISKSTYS

echo -e "\n\n\t Reading $ONDISKSTYS and finding candidates for removal.  Removal candidates will be written to $RMCANDIDATES"
findcandidates $ONDISKSTYS $1
echo -e "\n\n\t checking and removing studies "
checkAndRemove $RMCANDIDATES 

rm -f $RMCANDIDATES
rm -f $ONDISKSTYS
