#!/bin/bash
###############################################################################
#
#	Author: 	Tony Bowles
#	Date:		Aug 20 2009
#	Purpose:	Add/Remove filters from lists	
#	Params:		$1 = full path to filter file. For example:
#			/home/medsrv/data/users/jim/filters/default.rec
#
###############################################################################
DEBUG="FALSE"
###############################################################################
#
# Defaults
#
###############################################################################

isAtSystem=`echo "$1" | grep @system`

if [ "x$isAtSystem" != "x" ] ; then
	exit
fi

OIFS="$IFS"
IFS="
"
# A filter to add to lists:
#	Date newer than 7 days
LimitFilter="qf_DATE=\"(-7 days)()()\""


# An existing Filter to remove:
# 	Recieve date newer than 14 days
#RemoveFilter="qf_RCVD=\"(-14 days)()()\""
#RemoveFilter="qf_DATE=\"(-7 days)()()\""

# Tempfiles
TMPGrep="$HOME/tmp/$$.out"
TMPFilter="$HOME/tmp/$$.filter"
TMPFinal="$HOME/tmp/$$.final"

list="$1"

echo "$LimitFilter" > $TMPFilter

# Is there a filter we need to remove???
if [ "$RemoveFilter" != "" ] ; then
	cat $list | grep -v "$RemoveFilter" > $TMPGrep
else
	cat $list > $TMPGrep
fi

#  Combine the existing list definition file (possibly modified) and the new filter 
cat $TMPGrep $TMPFilter > $TMPFinal

if [ "$DEBUG" = "TRUE" ] ; then
	echo -e "\n\n*****************  Original filter: ************************"
	cat $1
	echo -e "\n\n*****************  Updated filter: ************************"
	cat $TMPFinal
	echo -e "\n\n"
	echo -e "Updating $1 ...\n\n"
fi

# Put the corrected list definition file in place
mv $TMPFinal $1

# Cleanup
rm -f $TMPGrep $TMPFilter $TMPFinal

IFS="$OIFS"
