#! /bin/bash

debug=1

# USER is passed in as part of the user environment (preset from the user's bash session)
user=$USER
cmd="$1"
exclude="$2"

excludeotherservers=$(echo $exclude|grep -i otherservers)
excludeparent=$(echo $exclude|grep -i parent)
excludechildren=$(echo $exclude|grep -i children)

MEDUSR="medsrv"
MYSQL_HOME="/home/medsrv/component/mysql"
OTHERSERVERS=""
OTHERSERVERSFILE="/home/image/otherservers"

if [ -z "$excludeotherservers" ] ; then
    [ -f "$OTHERSERVERSFILE" ] && . $OTHERSERVERSFILE
fi

if [ "$user" == "root" ]; then
    # Query info about parent or child servers
    [ -z "$excludeparent" ] && \
        PARENT=$(su - $MEDUSR -c "$MYSQL_HOME/bin/mysql -N -B -e 'select HOST from Target where TYPE = \"P\";' imagemedical")
    [ -z "$excludechildren" ] && \
        CHILDREN=$(su - $MEDUSR -c "$MYSQL_HOME/bin/mysql -N -B -e 'select HOST from Target where TYPE = \"C\";' imagemedical")
elif [ "$user" == "medsrv" ]; then
    [ -z "$excludeparent" ] && \
        PARENT=$($MYSQL_HOME/bin/mysql -N -B -e "select HOST from Target where TYPE = 'P';" imagemedical)
    [ -z "$excludechildren" ] && \
        CHILDREN=$($MYSQL_HOME/bin/mysql -N -B -e "select HOST from Target where TYPE = 'C';" imagemedical)
else
    echo "You must run this script either as 'root' or as 'medsrv'"
    exit 1
fi

serverlist="$PARENT $CHILDREN $OTHERSERVERS"

[ -n "$PARENT" ] && echo "Info: Parent server(s) found: $PARENT."
[ -n "$CHILDREN" ] && echo "Info: Child server(s) found: `for e in $CHILDREN; do echo -n [$e] ;done`."
[ -n "$OTHERSERVERS" ] && echo "Info: Other server(s) found: `for e in $OTHERSERVERS; do echo -n [$e] ;done`."

if [ -z "$cmd" -o "$cmd" == "shell" ]; then
    echo "No command specified......"
    echo "Switching to interactive mode."
    operation="shell"
    unset cmd
else
    operation="$cmd"
fi

if [ -n "$serverlist" -a -n "$debug" ]; then
    echo "Servers to execute '$operation':"
    for target in $serverlist; do
        shortname=$(grep $target /etc/hosts|awk '{print $2}'|head -1)
        [ -z "$shortname" ] && shortname=$target
        echo "$target  [ $shortname ]"
    done
    echo "Press enter to continue"
    echo "or Control-C to abort."
fi


read a

for target in $serverlist; do
    shortname=$(grep $target /etc/hosts|awk '{print $2}'|head -1)
    [ -z "$shortname" ] && shortname=$target
    [ -n "$cmd" ] && echo "Executing $cmd on $target [ $shortname ]..." || echo "Logging in to $target [ $shortname ]  interactively.."
    ssh ${user}@${target} "$cmd"
    if [ $? -ne 0 ]; then
        echo "$cmd returned with error $?"
        echo "Problem on host $target"
        problemlist=$(echo $problemlist $target)
    fi
done

if [ -n "$problemlist" ]; then
    echo "ALERT!"
    echo "An error occurred while executing $operation on the following servers:"
    echo -e $problemlist|sed 's/ /\n/g'
    echo
    echo "Check that the server's IP is correct in the device table and that"
    echo "the target is pingable"
    echo
    echo "Execution completed with errors."
fi

