#! /bin/bash

INFOLOG=/home/medsrv/var/log/info.log
ME=$(hostname -s)
MYLOG=$ME.log
TZ=$(date | awk '{print $5}')
WLLOG=wl.log

#echo "All times are normalized to $ME's time
#
#        PbR PbD and SRt files are not considered
#
#        # srtime = study registered on child
#        # srtime2 = study registered on parent
#        # fotime = first object received on child
#        # lotime = last object received on child
#        # fortime = first object registered on child
#        # lortime = last object registered on child
#        # fotime2 = first object received on parent
#        # lotime2 = last object received on parent
#        # fortime2 = first object registered on parent
#        # lortime2 = last object registered on parent
#        # hostid = host id of child (from devices table)
#        # numimgs = number of image objects
#        # size = study size
#        # modality = modality
#        # modality_ae = originating hostid (from child's devices table)
#
#" > timedata.csv
echo "styiuid,'first received (child)','last received (child)','first registered (child)','last registered (child)','study registered (child)','first received (hub)','last received (hub)','first registered (hub)','last registered (hub)','study registered (hub)',hostid,numimgs,size,modality,modality_ae,'first registered (wl)','last registered (wl)'" > timedata.csv

getStudyproperty_() {

    local styiuid=$1
    local prop=$2

    res=$(echo "select $prop from Dcstudy where styiuid = '$styiuid';"|~/component/mysql/bin/mysql -N imagemedical)
    echo $res
}


getModality_() {

    local styiuid=$1
    local prop="MODALITY"

    getStudyproperty_ $styiuid $prop
}

getModalityAE_() {

    local styiuid=$1
    local logtocheck=$2

    grep "storescpreg" $logtocheck |grep $styiuid|head -1| awk '{print $13}'|sed 's/\]//'
}

getStudysize_() {

    local styiuid=$1
    local prop="SUMSIZE"

    getStudyproperty_ $styiuid $prop
}

getNumimages_() {

    local styiuid=$1
    local prop="NUMOFIMG"

    getStudyproperty_ $styiuid $prop
}

getTimedelta_() {

    local hostid=$1
    local ip=$2
    local localtime
    local remotetime
    local delta

    remotetime=$(ssh $ip "date +%s")
    localtime=$(date +%s)

    delta=$(($localtime - $remotetime))
#    delta2=$(($remotetime - $localtime))

    echo "$delta"

}

applyDelta_() {

    local remotetime=$1
    local delta=$2

    echo $(($remotetime + $delta))
}
    
getLogInfo_() {

    local hostid=$1
    local ip=$2

    ssh $ip grep -E "'(INFO (STUDY|OBJECT) acquire|storescp2|storescpreg)'" $INFOLOG | grep -v PbD | grep -v PbR| grep -v SRt > $hostid.log
}

convToSeconds_() {

    local datestring=$1
    echo $(date --date="$1" +%s)

}

convToDate_() {

    local secondsstring=$1
    echo $(date --date="1970-01-01 UTC $secondsstring seconds" +"%T")

}

if [ -n "$1" ]; then
    children=$(echo "select ID from Target where ID = '$1';" | ~/component/mysql/bin/mysql -N imagemedical)
else
    children=$(echo "select ID from Target where TYPE = 'C';" | ~/component/mysql/bin/mysql -N imagemedical)
fi

if [ -z "$children" ]; then
    echo 
    echo "Usage:"
    echo "$0 [optional hostid]"
    echo
    echo "Valid hostids are:"
    echo "select ID from Target where TYPE = 'C';" | ~/component/mysql/bin/mysql -N imagemedical
    echo
    echo "Default action is to check all children.  If you got this message after running"
    echo "the script with no arguments, or if there are not valid hostids listed above, "
    echo "there are probably no child servers configured on this server"
    echo
fi

wl=$(echo "select ID from Target where TYPE = 'P';" | ~/component/mysql/bin/mysql -N imagemedical)

# Get study acquire info from child servers
for hostid in $children $wl; do
    ip=$(echo "select HOST from Target where ID = '$hostid';" | ~/component/mysql/bin/mysql -N imagemedical)
    echo "Checking clock on $hostid $ip"
    td=$(getTimedelta_ $hostid $ip)
    echo "Time on $hostid is local server time offset by $td seconds"
    # Ugly hack to get rid of "-" chars in hostids (- is invalid in a variable name)
    tdhostid=$(echo $hostid|sed 's/\-//')
    export "${tdhostid}_td"="${td}"
    echo "Getting log info on $hostid $ip"
    getLogInfo_ $hostid $ip
done


# Get info for this server
grep -E "(INFO (STUDY|OBJECT) acquire|storescp2|storescpreg)" $INFOLOG |grep -v PbR| grep -v SRt|grep -v PbD > $MYLOG

if [ -n "$wl" ]; then
    wltdhostid=$(echo $wl|sed 's/\-//')
    wltd=${wltdhostid}_td
    WLLOG=$wl.log
fi

for hostid in $children; do
    CHILDLOG=$hostid.log
    tdhostid=$(echo $hostid|sed 's/\-//')
    td=${tdhostid}_td
    cat $CHILDLOG | sed '/storescp2/d' | sed '/storescpreg/d' | awk '{print $11}'| sort -u | while read styiuid; do
        # srtime = study registered on child
        # srtime2 = study registered on parent
        # fotime = first object received on child
        # lotime = last object received on child
        # fortime = first object registered on child
        # lortime = last object registered on child
        # fotime2 = first object received on parent
        # lotime2 = last object received on parent
        # fortime2 = first object registered on parent
        # lortime2 = last object registered on parent
        # hostid = host id of child (from devices table)
        # #images = number of image objects
        # size = study size
        # modality = modality
        # modality_ae = originating hostid (from child's devices table)

        # wlfortime = first object registered on wl server
        # wllortime = last object registered on wl server

        fortype=$(grep $styiuid $CHILDLOG|grep "INFO OBJECT acquire"|head -1| awk '{print $21}')
        lortype=$(grep $styiuid $CHILDLOG|grep "INFO OBJECT acquire"|tail -1| awk '{print $21}')

        # Get date in "month day time" format
        fortime=$(grep $styiuid $CHILDLOG|grep "INFO OBJECT acquire"|head -1| awk '{print $1 " " $2 " " $3}')
        lortime=$(grep $styiuid $CHILDLOG|grep "INFO OBJECT acquire"|tail -1| awk '{print $1 " " $2 " " $3}')
        fotime=$(grep $styiuid $CHILDLOG|grep "storescp2"|head -1| awk '{print $1 " " $2 " " $3}')
        lotime=$(grep $styiuid $CHILDLOG|grep "storescp2"|tail -1| awk '{print $1 " " $2 " " $3}')
        srtime=$(grep $styiuid $CHILDLOG|grep "INFO STUDY acquire"|head -1| awk '{print $1 " " $2 " " $3}')

        fortime2=$(grep $styiuid $MYLOG|grep "INFO OBJECT acquire"|head -1| awk '{print $3}')
        fotime2=$(grep $styiuid $MYLOG|grep "storescp2"|head -1| awk '{print $3}')
        lotime2=$(grep $styiuid $MYLOG|grep "storescp2"|tail -1| awk '{print $3}')
        lortime2=$(grep $styiuid $MYLOG|grep "INFO OBJECT acquire"|tail -1| awk '{print $3}')
        fortype2=$(grep $styiuid $MYLOG|grep "INFO OBJECT acquire"|head -1| awk '{print $21}')
        lortype2=$(grep $styiuid $MYLOG|grep "INFO OBJECT acquire"|tail -1| awk '{print $21}')
        srtime2=$(grep $styiuid $MYLOG|grep "INFO STUDY acquire"|head -1| awk '{print $3}')

        size=$(getStudysize_ $styiuid)
        numimgs=$(getNumimages_ $styiuid)
        modality=$(getModality_ $styiuid)
        modality_ae=$(getModalityAE_ $styiuid $CHILDLOG)

        if [ -n "$wl" ]; then
           wlfortime=$(grep $styiuid $WLLOG|grep "INFO OBJECT acquire"|head -1| awk '{print $1 " " $2 " " $3}')
           wllortime=$(grep $styiuid $WLLOG|grep "INFO OBJECT acquire"|tail -1| awk '{print $1 " " $2 " " $3}')
        fi

        # Don't apply time delta to *time2 times, because those are my time and don't need to be adjusted!
        for datetime in fortime lortime fotime lotime srtime ; do
           [ -z "${!datetime}" ] && continue
           # Convert to seconds since epoch
           export "$datetime"=$(convToSeconds_ "${!datetime}") 
           # Apply delta
           export "$datetime"=$(applyDelta_ "${!datetime}" ${!td})
           # Convert back to time
           export "$datetime"=$(convToDate_ "${!datetime}")
        done
  
        if [ -n "$wl" ]; then
            for datetime in wlfortime wllortime; do
               [ -z "${!datetime}" ] && continue
               # Convert to seconds since epoch
               export "$datetime"=$(convToSeconds_ "${!datetime}") 
               # Apply delta
               export "$datetime"=$(applyDelta_ "${!datetime}" ${!wltd})
               # Convert back to time
               export "$datetime"=$(convToDate_ "${!datetime}")
            done
        fi

        echo "styiuid : $styiuid:"
        echo -e "\t\t $hostid time delta: ${!td}"
        echo -e "\t\t $wl time delta: ${!wltd}"
        echo -e "\t\t First object received on $hostid: $fotime"
        echo -e "\t\t First object registered on $hostid: $fortime ($fortype)"
        echo -e "\t\t Last object received on $hostid: $lotime"
        echo -e "\t\t Last object registered on $hostid: $lortime ($lortype)" 
        echo -e "\t\t Study registered on $hostid : $srtime"
        echo -e "\t\t First object received on $ME : $fotime2"
        echo -e "\t\t First object registered on $ME : $fortime2 ($fortype2)"
        echo -e "\t\t Last object received on $ME : $lotime2"
        echo -e "\t\t Last object registered on $ME : $lortime2 ($lortype2)"
        echo -e "\t\t Study registered on $ME : $srtime2"
        echo -e "\t\t Child hostid : $hostid"
        echo -e "\t\t Number of images : $numimgs"
        echo -e "\t\t Study size : $size"
        echo -e "\t\t Modality : $modality"
        echo -e "\t\t Station name : $modality_ae"

        echo -e "\t\t First object registered on $wl: $wlfortime"
        echo -e "\t\t Last object registered on $wl: $wllortime"

        # Create csv file for spreadsheet

        echo "$styiuid,$fotime,$lotime,$fortime,$lortime,$srtime,$fotime2,$lotime2,$fortime2,$lortime2,$srtime2,$hostid,$numimgs,$size,$modality,$modality_ae,$wlfortime,$wllortime" >> timedata.csv

    done
done

cp -va timedata.csv ~/component/download/

